==> wagon_3.3.1.orig.tar.xz: maven-wagon-wagon-3.3.1/wagon-providers/wagon-http/src/test/java/org/apache/maven/wagon/providers/http/ErrorWithMessageServlet.java <==
package org.apache.maven.wagon.providers.http;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

/**
 * User: jdumay
 * Date: 24/01/2008
 * Time: 17:25:27
 */
public class ErrorWithMessageServlet
    extends HttpServlet
{
    private static final long serialVersionUID = -1419714266724471393L;

    public static final String MESSAGE = "it sucks!";

    public void service( HttpServletRequest request, HttpServletResponse response )
        throws ServletException, IOException
    {
        if ( request.getRequestURL().toString().contains( "401" ) )
        {
            response.sendError( 401, MESSAGE );
        }
        else if ( request.getRequestURL().toString().contains( "403" ) )
        {
            response.sendError( 403, MESSAGE );
        }
        else if ( request.getRequestURL().toString().contains( "407" ) )
        {
            response.sendError( 407, MESSAGE );
        }
        else if ( request.getRequestURL().toString().contains( "500" ) )
        {
            response.sendError( 500, MESSAGE );
        }

    }
}

==> wagon_3.5.2.orig.tar.xz: maven-wagon-wagon-3.5.2/wagon-providers/wagon-http/src/test/java/org/apache/maven/wagon/providers/http/ErrorWithMessageServlet.java <==
package org.apache.maven.wagon.providers.http;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

/**
 * User: jdumay
 * Date: 24/01/2008
 * Time: 17:25:27
 */
public class ErrorWithMessageServlet
    extends HttpServlet
{
    private static final long serialVersionUID = -1419714266724471393L;

    public static final String MESSAGE = "it sucks!";

    public void service( HttpServletRequest request, HttpServletResponse response )
        throws ServletException, IOException
    {
        if ( request.getPathInfo().endsWith( "/401" ) )
        {
            response.sendError( 401, MESSAGE );
        }
        else if ( request.getPathInfo().endsWith( "/403" ) )
        {
            response.sendError( 403, MESSAGE );
        }
        else if ( request.getPathInfo().endsWith( "/404" ) )
        {
            response.sendError( 404, MESSAGE );
        }
        else if ( request.getPathInfo().endsWith( "/407" ) )
        {
            response.sendError( 407, MESSAGE );
        }
        else if ( request.getPathInfo().endsWith( "/500" ) )
        {
            response.sendError( 500, MESSAGE );
        }

    }
}
